Struct tokio_timer::clock::Clock
source · pub struct Clock { /* private fields */ }Expand description
A handle to a source of time.
Clock instances return Instant values corresponding to “now”. The source
of these values is configurable. The default source is Instant::now().
Implementations
sourceimpl Clock
impl Clock
sourcepub fn new() -> Clock
pub fn new() -> Clock
Return a new Clock instance that uses the current execution context’s
source of time.
sourcepub fn new_with_now<T: Now>(now: T) -> Clock
pub fn new_with_now<T: Now>(now: T) -> Clock
Return a new Clock instance that uses now as the source of time.