Module throttle

Module throttle 

Slow down a stream by enforcing a delay between items.

Structs

Throttle
Slow down a stream by enforcing a delay between items.
ThrottleError
Either the error of the underlying stream, or an error within tokio’s timing machinery.