pub fn set_default(handle: &Handle) -> DefaultGuardExpand description
Sets handle as the default timer, returning a guard that unsets it on drop.
Panics
This function panics if there already is a default timer set.
pub fn set_default(handle: &Handle) -> DefaultGuardSets handle as the default timer, returning a guard that unsets it on drop.
This function panics if there already is a default timer set.