A configurable source of time.
This module provides an API to get the current instant in such a way that the source of time may be configured. This allows mocking out the source of time in tests.
The now function returns the current Instant. By default, it delegates
to Instant::now.
The source of time used by now can be configured by implementing the
Now trait and passing an instance to with_default.
Structs
- Clock
- A handle to a source of time.
- Default
Guard - A guard that resets the current
ClocktoNonewhen dropped.
Traits
Functions
- now
- Returns an
Instantcorresponding to “now”. - set_
default - Sets
clockas the default clock, returning a guard that unsets it on drop. - with_
default - Set the default clock for the duration of the closure.